@@ -16,11 +16,17 @@ from halo_flask.providers.ssm.onprem_ssm import AbsOnPremClient
 logger = logging.getLogger(__name__)
 
 # for testing
+
 class OnPremClient(AbsOnPremClient):
     dict = {}
 
     def put_parameter(self, Name, Value, Type, Overwrite):
-        self.dict[Name] = Value
+        root = Name.split("/")
+        section_position = len(root) - 1
+        section_name = root[section_position]
+        params = [{'Name':section_name,'Value':Value}]
+        rec = {'Parameters' : params }
+        self.dict[Name.replace("/"+section_name,"")] = rec
 
     def get_parameters_by_path(self, Path, Recursive, WithDecryption):
         return self.dict[Path]
